@@ -3,12 +3,31 @@
 # print(pypiplot.__version__)
 
 from pypiplot import pypiplot
-print(dir(pypiplot))
+# print(dir(pypiplot))
+
+# %% Plot
+# Init
+pp = pypiplot(username='erdogant', savepath='D://REPOS/pypiplot/repo_data/')
+# Get download statistics
+results = pp.stats()
+
+# Store svg on github.io
+path = 'D://REPOS/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap.html'
+pp.plot_year(path=path, vmin=700)
+# Store all repo info in github.io
+path = 'D://REPOS/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap_repos.html'
+pp.plot(path=path, vmin=100)
+
 
 # %%
-pp = pypiplot(username='erdogant', savepath='D://PY/REPOSITORIES/pypiplot/repo_data/')
+pp = pypiplot(username='erdogant')
+
+pp.stats(repo='distfit')
+pp.plot_year()
+pp.plot(vmin=25)
 
 # %% Update all
+pp = pypiplot(username='erdogant', savepath='D://REPOS/pypiplot/repo_data/')
 pp.update()
 
 # %% Update single repo
@@ -52,21 +71,23 @@ results = pp.stats(repo='bnlearn')
 pp.plot_year()
 
 # %%
+pp.update()
 results = pp.stats()
 pp.plot_year(vmin=700)
 pp.plot(vmin=25)
 
 # %% Plot
 # Init
-pp = pypiplot(username='erdogant', savepath='D://PY/REPOSITORIES/pypiplot/repo_data/')
+pp = pypiplot(username='erdogant', savepath='D://REPOS/pypiplot/repo_data/')
 # Get download statistics
 results = pp.stats()
 
 # Store svg on github.io
-path = 'D://PY/REPOSITORIES/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap.html'
+path = 'D://REPOS/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap.html'
 pp.plot_year(path=path, vmin=700)
 # Store all repo info in github.io
-path = 'D://PY/REPOSITORIES/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap_repos.html'
+path = 'D://REPOS/erdogant.github.io/docs/imagesc/pypi/pypi_heatmap_repos.html'
 pp.plot(path=path, vmin=100)
 
 # %%
+results['data'].cumsum().plot()
